==> earthkit-0.10.0.tar.gz: earthkit-0.10.0/README.md <==
<a href="https://github.com/ecmwf/earthkit">
  <p align="center">
    <picture>
      <source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-dark.svg" media="(prefers-color-scheme: dark)">
      <img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-light.svg" height="120">
    </picture>
  </p>
</a>

<p align="center">
  <a href="https://github.com/ecmwf/codex/raw/refs/heads/main/ESEE">
    <img src="https://github.com/ecmwf/codex/raw/refs/heads/main/ESEE/foundation_badge.svg" alt="ECMWF Software EnginE">
  </a>
  <a href="https://github.com/ecmwf/codex/raw/refs/heads/main/Project Maturity">
    <img src="https://github.com/ecmwf/codex/raw/refs/heads/main/Project Maturity/incubating_badge.svg" alt="Maturity Level">
  </a>
  <a href="https://opensource.org/licenses/apache-2-0">
    <img src="https://img.shields.io/badge/License-Apache%202.0-blue.svg" alt="License">
  </a>
  <a href="https://pypi.python.org/pypi/earthkit/">
    <img src="https://badge.fury.io/py/earthkit.svg" alt="PyPI version fury.io">
  </a>
  <a href="https://pypi.python.org/pypi/earthkit/">
    <img src="https://img.shields.io/pypi/pyversions/earthkit.svg" alt="PyPI pyversions">
  </a>
</p>

> \[!IMPORTANT\]
> This software is **Incubating** and subject to ECMWF's guidelines on [Software Maturity](https://github.com/ecmwf/codex/raw/refs/heads/main/Project%20Maturity).

**earthkit** is an open-source project led by ECMWF, providing powerful tools for speeding up weather and climate science workflows by simplifying data access, processing, analysis, visualisation and much more.

# The earthkit ecosystem

| | | |
|:-------------------------:|:-------------------------:|:-------------------------:|
| <a href="https://github.com/ecmwf/earthkit-data"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-data-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-data-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-plots"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-plots-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-plots-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-meteo"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-meteo-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-meteo-light.svg"></picture></a> |
| <a href="https://github.com/ecmwf/earthkit-regrid"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-regrid-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-regrid-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-climate"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-climate-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-climate-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-geo"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-geo-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-geo-light.svg"></picture></a> |
| <a href="https://github.com/ecmwf/earthkit-time"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-time-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-time-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-transforms"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-transforms-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-transforms-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-hydro"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-hydro-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-hydro-light.svg"></picture></a> |

## Documentation

The documentation can be found at https://earthkit.readthedocs.io/.

## License

[Apache License 2.0](LICENSE) In applying this license, ECMWF does not waive the privileges and immunities
granted to it by virtue of its status as an intergovernmental organisation nor does it submit to any jurisdiction.

==> earthkit-0.10.1.tar.gz: earthkit-0.10.1/README.md <==
<a href="https://github.com/ecmwf/earthkit">
  <p align="center">
    <picture>
      <source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-dark.svg" media="(prefers-color-scheme: dark)">
      <img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-light.svg" height="120">
    </picture>
  </p>
</a>

<p align="center">
  <a href="https://github.com/ecmwf/codex/raw/refs/heads/main/ESEE">
    <img src="https://github.com/ecmwf/codex/raw/refs/heads/main/ESEE/foundation_badge.svg" alt="ECMWF Software EnginE">
  </a>
  <a href="https://github.com/ecmwf/codex/raw/refs/heads/main/Project Maturity">
    <img src="https://github.com/ecmwf/codex/raw/refs/heads/main/Project Maturity/incubating_badge.svg" alt="Maturity Level">
  </a>
  <!-- <a href="https://codecov.io/gh/ecmwf/earthkit">
    <img src="https://codecov.io/gh/ecmwf/earthkit/branch/main/graph/badge.svg" alt="Code Coverage">
  </a> -->
  <a href="https://opensource.org/licenses/apache-2-0">
    <img src="https://img.shields.io/badge/Licence-Apache 2.0-blue.svg" alt="Licence">
  </a>
  <a href="https://github.com/ecmwf/earthkit/releases">
    <img src="https://img.shields.io/github/v/release/ecmwf/earthkit?color=purple&label=Release" alt="Latest Release">
  </a>
</p>

<p align="center">
  <!-- <a href="#quick-start">Quick Start</a>
  • -->
  <a href="#installation">Installation</a>
  •
  <a href="https://earthkit.readthedocs.io/">Documentation</a>
</p>

> \[!IMPORTANT\]
> This software is **Incubating** and subject to ECMWF's guidelines on [Software Maturity](https://github.com/ecmwf/codex/raw/refs/heads/main/Project%20Maturity).

**earthkit** is an open-source project led by ECMWF, providing powerful tools for speeding up weather and climate science workflows by simplifying data access, processing, analysis, visualisation and much more.

## The earthkit ecosystem

| | | |
|:-------------------------:|:-------------------------:|:-------------------------:|
| <a href="https://github.com/ecmwf/earthkit-data"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-data-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-data-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-plots"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-plots-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-plots-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-meteo"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-meteo-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-meteo-light.svg"></picture></a> |
| <a href="https://github.com/ecmwf/earthkit-regrid"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-regrid-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-regrid-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-climate"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-climate-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-climate-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-geo"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-geo-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-geo-light.svg"></picture></a> |
| <a href="https://github.com/ecmwf/earthkit-time"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-time-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-time-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-transforms"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-transforms-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-transforms-light.svg"></picture></a> | <a href="https://github.com/ecmwf/earthkit-hydro"><picture><source srcset="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-hydro-dark.svg" media="(prefers-color-scheme: dark)"><img src="https://github.com/ecmwf/logos/raw/refs/heads/main/logos/earthkit/earthkit-hydro-light.svg"></picture></a> |

<!-- ## Quick Start -->

## Installation

Install from PyPI:

```
pip install earthkit
```

More details can be found at https://earthkit.readthedocs.io/en/latest/install.html.

## Licence

```
Copyright 2023, European Centre for Medium Range Weather Forecasts.

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

In applying this licence, ECMWF does not waive the privileges and immunities
granted to it by virtue of its status as an intergovernmental organisation
nor does it submit to any jurisdiction.
```
